@@ -12,7 +12,7 @@ from ipywidgets import (Text, VBox, HBox, Label, Password, Button, Layout, Tab,
                         Output, Dropdown, FloatText, BoundedIntText, Combobox)
 
 from cbm.utils import config, data_options
-from cbm.sources import db
+from cbm.sources import db, db_requests
 
 
 def api(mode=None):
@@ -53,13 +53,17 @@ def api(mode=None):
     @wb_save.on_click
     def wb_save_on_click(b):
         progress.clear_output()
-        config.update(['api', 'url'], str(wt_url.value))
-        config.update(['api', 'user'], str(wt_user.value))
+        config.set_value(['api', 'url'], str(wt_url.value).replace(' ', ''))
+        config.set_value(['api', 'user'], str(wt_user.value).replace(' ', ''))
         if wt_pass.value != '':
-            config.update(['api', 'pass'], str(wt_pass.value))
-        outlog("API information is updated")
+            config.set_value(['api', 'pass'], str(
+                wt_pass.value).replace(' ', ''))
+        outlog("The RESTful API credentials are saved.")
 
-    wbox = VBox([wt_url, wt_user, wt_pass, wb_save, progress])
+    wbox = VBox([HBox([wt_url,
+                       Label("Format: http://0.0.0.0/ or https://0.0.0.0/")]),
+                 wt_user, wt_pass,
+                 HBox([wb_save, progress])])
 
     return wbox
 
@@ -157,19 +161,19 @@ def direct_conn(db='main'):
     def wb_save_on_click(b):
         progress.clear_output()
         # Save database connection information
-        config.update(['db', db, 'host'], str(db_host.value))
-        config.update(['db', db, 'port'], str(db_port.value))
-        config.update(['db', db, 'name'], str(db_name.value))
-        config.update(['db', db, 'user'], str(db_user.value))
+        config.set_value(['db', db, 'host'], str(db_host.value))
+        config.set_value(['db', db, 'port'], str(db_port.value))
+        config.set_value(['db', db, 'name'], str(db_name.value))
+        config.set_value(['db', db, 'user'], str(db_user.value))
         if db_pass.value != '':
-            config.update(['db', db, 'conn', 'pass'], str(db_pass.value))
+            config.set_value(['db', db, 'conn', 'pass'], str(db_pass.value))
         # Save Object storage connection information
-        config.update(['obst', 'osdias'], str(os_dias.value))
-        config.update(['obst', 'oshost'], str(os_host.value))
-        config.update(['obst', 'bucket'], str(os_bucket.value))
-        config.update(['obst', 'access_key'], str(os_access_key.value))
+        config.set_value(['obst', 'osdias'], str(os_dias.value))
+        config.set_value(['obst', 'oshost'], str(os_host.value))
+        config.set_value(['obst', 'bucket'], str(os_bucket.value))
+        config.set_value(['obst', 'access_key'], str(os_access_key.value))
         if os_secret_key.value != '':
-            config.update(['obst', 'secret_key'], str(os_secret_key.value))
+            config.set_value(['obst', 'secret_key'], str(os_secret_key.value))
 
         outlog("All changes are saved.")
 
@@ -183,7 +187,7 @@ def direct_conn(db='main'):
 def direct_settings():
     values = config.read()
     ds_def = values['set']['dataset']
-    ds_dye = values['set']['ds_year']
+    # ds_dye = values['set']['ds_year']
     if ds_def not in [d for d in values['dataset']]:
         ds_def = [d for d in values['dataset']][0]
 
@@ -195,14 +199,6 @@ def direct_settings():
         layout=Layout(width='200px')
     )
 
-    dsy = Dropdown(
-        options=[int(dsc.value.split('_')[-1])],
-        value=int(ds_dye),
-        description='Dataset year:',
-        disabled=False,
-        layout=Layout(width='180px')
-    )
-
     btn_refresh = Button(
         layout=Layout(width='35px'),
         icon='fa-refresh')
@@ -211,32 +207,20 @@ def direct_settings():
     def btn_refresh_on_click(b):
         values = config.read()
         ds_c = values['set']['dataset']
-        ds_y = values['set']['ds_year']
         dsc.options = [d for d in values['dataset']]
-        dsy.options = [int(y) for y in values['dataset']]
         dsc.value = ds_c
-        dsy.value = int(ds_y)
 
     def on_dsc_change(change):
-        config.update(['set', 'dataset'], dsc.value)
-        values = config.read()
-        ds_c = values['set']['dataset']
-        dsy.options = [int(y) for y in values['dataset'][ds_c]]
+        config.set_value(['set', 'dataset'], dsc.value)
     dsc.observe(on_dsc_change, 'value')
 
-    def on_dsy_change(change):
-        config.update(['set', 'ds_year'], str(dsy.value))
-    dsy.observe(on_dsy_change, 'value')
-
     bt_set = Button(layout=Layout(width='40px'), icon='cogs',
                     tooltip="Configure this dataset")
     bt_new = Button(layout=Layout(width='40px'), icon='plus',
                     tooltip="Add new dataset configuration")
-    bt_rec = Button(layout=Layout(width='40px'), icon='trash-alt',
+    bt_del = Button(layout=Layout(width='40px'), icon='trash-alt',
                     tooltip='Delete dataset configuration')
-    bt_rey = Button(layout=Layout(width='40px'), icon='trash-alt',
-                    tooltip='Delete only the selected year.')
-    dsc_box = HBox([dsc, btn_refresh, bt_rec, dsy, bt_set, bt_rey, bt_new])
+    dsc_box = HBox([dsc, btn_refresh, bt_del, bt_set, bt_new])
 
     progress = Output()
 
@@ -247,18 +231,18 @@ def direct_settings():
     def dsc_config(dsc_value):
         values = config.read()
         ds_db = Dropdown(
-            options=["1"],
-            value="1",
+            options=list(values['db'].keys()),
+            value="main",
             description='Database:',
             disabled=False,
-            layout=Layout(width='140px')
+            layout=Layout(width='200px')
         )
 
         try:
-            with open(f"{config.get_value(['paths','temp'])}tb_prefix", 'r') as f:
-                code_value = f.read()
+            with open(f"{values['paths']['temp']}tb_prefix", 'r') as f:
+                code_value = f.read().split('_')[0]
         except Exception:
-            code_value = dsc_value
+            code_value = dsc_value.split('_')[0]
 
         ds_code = Combobox(
             value=code_value,
@@ -271,7 +255,7 @@ def direct_settings():
             tooltip='Lowercase AOI code name for the dataset (5chr max).'
         )
         ds_year = BoundedIntText(
-            value=int(dsy.value),
+            value=int(dsc_value.split('_')[1]),
             min=1980,
             max=2100,
             step=1,
@@ -318,12 +302,12 @@ def direct_settings():
             tooltip='Get center point from database.'
         )
 
-        ds_box = HBox([ds_code, ds_year, ds_desc])
+        ds_box = HBox([ds_code, ds_year, ds_desc, ds_db])
         map_box = HBox([Label("Map center: "), map_cent_lat,
                         map_cent_lon, bt_get_center, map_zoom])
 
         info_config = Label(
-            """Change 'AOI code' value to create a new configuration set or
+            """Change 'AOI code' or 'Year' value to create a new configuration set or
             leave the same 'AOI code' value to configure the selected one.""")
 
         db_set = values['dataset'][dsc_value]['db']
@@ -354,7 +338,7 @@ def direct_settings():
 
         def get_pr_columns():
             try:
-                colms = db.table_columns(tb_pr.value, 1, None)
+                colms = db.table_columns(tb_pr.value, ds_db.value, None)
                 if colms is None:
                     return []
                 else:
@@ -396,8 +380,6 @@ def direct_settings():
             tc_cc.options = get_pr_columns()
         tb_pr.observe(on_tb_pr_change, 'value')
 
-        parcel_box = HBox([tb_pr, tc_id, tc_cn, tc_cc])
-
         tb_s2 = Dropdown(
             options=get_tb_list(),
             value=config.autoselect(
@@ -433,7 +415,7 @@ def direct_settings():
         def bt_get_center_on_click(b):
             import json
             center_json = json.loads(
-                db.getTableCentroid(tb_pr.value)['center'][0])
+                db_requests.getTableCentroid(tb_pr.value)['center'][0])
             map_cent_lat.value = round(center_json['coordinates'][1], 2)
             map_cent_lon.value = round(center_json['coordinates'][0], 2)
             map_zoom.value = 10
@@ -442,43 +424,46 @@ def direct_settings():
         def wb_save_on_click(b):
             progress.clear_output()
             dscode = ds_code.value
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'tables', 'dias_catalog'], str(tb_dc.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'tables', 'parcels'], str(tb_pr.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'pcolumns', 'parcels_id'], str(tc_id.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'pcolumns', 'crop_names'], str(tc_cn.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'pcolumns', 'crop_codes'], str(tc_cc.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'tables', 's2'], str(tb_s2.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'tables', 'bs'], str(tb_bs.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'tables', 'c6'], str(tb_6c.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'db'], str(ds_db.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'desc'], str(ds_desc.value))
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}', 'center'],
-                          f"{map_cent_lat.value},{map_cent_lon.value}")
-            config.update(['dataset', f'{dscode}_{str(ds_year.value)}',
-                           'zoom'], str(map_zoom.value))
-            config.update(['set', 'dataset'], f'{dscode}_{str(ds_year.value)}')
-            config.update(['set', 'ds_year'], str(ds_year.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'tables', 'dias_catalog'], str(tb_dc.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'tables', 'parcels'], str(tb_pr.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'pcolumns', 'parcels_id'], str(tc_id.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'pcolumns', 'crop_names'], str(tc_cn.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'pcolumns', 'crop_codes'], str(tc_cc.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'tables', 's2'], str(tb_s2.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'tables', 'bs'], str(tb_bs.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'tables', 'c6'], str(tb_6c.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'db'], str(ds_db.value))
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'desc'], str(ds_desc.value))
+            config.set_value(
+                ['dataset', f'{dscode}_{str(ds_year.value)}', 'center'],
+                f"{map_cent_lat.value},{map_cent_lon.value}")
+            config.set_value(['dataset', f'{dscode}_{str(ds_year.value)}',
+                              'zoom'], str(map_zoom.value))
+            config.set_value(['set', 'dataset'],
+                             f'{dscode}_{str(ds_year.value)}')
+            config.set_value(['set', 'ds_year'], str(ds_year.value))
             values = config.read()
             ds_c = values['set']['dataset']
-            ds_y = values['set']['ds_year']
             dsc.options = [d for d in values['dataset']]
-            dsy.options = [int(y) for y in values['dataset'][ds_c]]
             dsc.value = ds_c
-            dsy.value = int(ds_y)
             outlog("The configurations are saved.")
 
-        return VBox([info_config, ds_box, parcel_box,
-                     tb_dc, tb_s2, tb_bs, tb_6c,
+        db_box = HBox([VBox([Label('Tables:'),
+                             tb_pr, tb_dc, tb_s2, tb_bs, tb_6c]),
+                       VBox([Label('Columns:'),
+                             HBox([tc_id, tc_cn, tc_cc])])])
+
+        return VBox([info_config, ds_box, db_box,
                      Label(''.join(info_map_text)), map_box, wb_save])
 
     dsc_new_box = HBox([])
@@ -501,8 +486,8 @@ def direct_settings():
             dsc_new_box.children = ()
             bt_set.icon = 'cogs'
 
-    @bt_rec.on_click
-    def bt_rec_on_click(b):
+    @bt_del.on_click
+    def bt_del_on_click(b):
         progress.clear_output()
         if len(dsc.options) > 1:
             config.delete(['dataset', dsc.value])
@@ -512,18 +497,6 @@ def direct_settings():
         else:
             outlog("Can not remove last configuration.")
 
-    @bt_rey.on_click
-    def bt_rey_on_click(b):
-        progress.clear_output()
-        if len(dsy.options) > 1:
-            config.delete(['dataset', dsc.value, str(dsy.value)])
-            outlog(f"Year {dsy.value} of dataset '{dsc.value}' is deleted.")
-            values = config.read()
-            dsy.options = [int(y) for y in values['dataset']
-                           [str(dsc.value)]]
-        else:
-            outlog("Can not remove last configuration.")
-
     wbox = VBox([Label("Datasets configurations."), dsc_box,
                  dsc_new_box, progress])
 
